Files
TheRock/rocm-libraries/projects/rocblas/clients/common/rocblas_parse_data.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

140 lines
4.5 KiB
C++

/* ************************************************************************
* Copyright (C) 2019-2024 Advanced Micro Devices, Inc. All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell cop-
* ies of the Software, and to permit persons to whom the Software is furnished
* to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IM-
* PLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
* COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
* IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNE-
* CTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*
* ************************************************************************ */
#include "rocblas_parse_data.hpp"
#include "client_utility.hpp"
#include "rocblas_data.hpp"
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <fcntl.h>
#include <iostream>
#include <string>
#include <sys/types.h>
// Parse YAML data
static std::string rocblas_parse_yaml(const std::string& yaml)
{
std::string tmp = rocblas_tempname();
auto exepath = rocblas_exepath();
std::string yaml_path;
if(!rocblas_file_exists(yaml.c_str()))
{
yaml_path = exepath + yaml;
}
else
{
yaml_path = yaml;
}
#ifdef WIN32
// Explicitly run via `python.exe`, without relying on the .py file being
// treated as an executable that should be run via the python interpreter.
std::string python_command_launcher = "python ";
#else
// Rely on the shebang in the file, e.g. `#!/usr/bin/env python3`.
std::string python_command_launcher = "";
#endif
auto cmd = python_command_launcher + exepath + "rocblas_gentest.py --template " + exepath
+ "rocblas_template.yaml -o " + tmp + " " + yaml_path;
rocblas_cerr << cmd << std::endl;
#ifdef WIN32
int status = std::system(cmd.c_str());
if(status == -1)
exit(EXIT_FAILURE);
#else
int status = system(cmd.c_str());
if(status == -1 || !WIFEXITED(status) || WEXITSTATUS(status))
exit(EXIT_FAILURE);
#endif
return tmp;
}
// Parse --data and --yaml command-line arguments
bool rocblas_parse_data(int& argc, char** argv, const std::string& default_file)
{
std::string filename;
char** argv_p = argv + 1;
bool help = false, yaml = false;
// Scan, process and remove any --yaml or --data options
for(int i = 1; argv[i]; ++i)
{
if(!strcmp(argv[i], "--data") || !strcmp(argv[i], "--yaml"))
{
if(!strcmp(argv[i], "--yaml"))
{
yaml = true;
}
if(filename != "")
{
rocblas_cerr << "Only one of the --yaml and --data options may be specified"
<< std::endl;
exit(EXIT_FAILURE);
}
if(!argv[i + 1] || !argv[i + 1][0])
{
rocblas_cerr << "The " << argv[i] << " option requires an argument" << std::endl;
exit(EXIT_FAILURE);
}
filename = argv[++i];
}
else
{
*argv_p++ = argv[i];
if(!help && (!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help")))
{
help = true;
rocblas_cout << "\n"
<< argv[0] << " [ --data <path> | --yaml <path> ] <options> ...\n"
<< std::endl;
}
}
}
// argc and argv contain remaining options and non-option arguments
*argv_p = nullptr;
argc = argv_p - argv;
if(filename == "-")
filename = "/dev/stdin";
else if(filename == "")
filename = default_file;
if(yaml)
filename = rocblas_parse_yaml(filename);
if(filename != "")
{
RocBLAS_TestData::set_filename(filename, yaml);
return true;
}
return false;
}